@@ -16,7 +16,7 @@ def create_chemicals():
     from biorefineries import lipidcane as lc, cornstover as cs
     chemicals = lc.chemicals['Water', 'Ethanol', 'Glucose', 'H3PO4', 'P4O10', 
                              'CO2', 'Octane', 'O2', 'CH4', 'Ash', 
-                             'Yeast', 'CaO', 'Lipid', 'Cellulose']
+                             'Yeast', 'CaO', 'TAG', 'Cellulose']
     chemicals += cs.chemicals['H2SO4', 'N2', 'SO2']
     chemicals = tmo.Chemicals([*chemicals, 'NH3'])
     Starch = chemicals.Cellulose.copy('Starch')
@@ -25,8 +25,8 @@ def create_chemicals():
     InsolubleProtein = chemicals.Cellulose.copy('InsolubleProtein')
     chemicals.extend([Starch, Fiber, SolubleProtein, InsolubleProtein])
     chemicals.NH3.at_state('l')
-    chemicals.NH3.V[0].Tmax = 500.
     chemicals.compile()
-    chemicals.set_synonym('Lipid', 'Oil')
+    chemicals.set_synonym('TAG', 'Oil')
+    chemicals.set_synonym('TAG', 'Lipid')
     chemicals.set_synonym('Water', 'H2O')
     return chemicals
\ No newline at end of file
