@@ -136,7 +136,7 @@ def create_chemicals():
     append_single_phase_chemical('AmmoniumSulfate')
     append_single_phase_chemical('NaNO3', 'SodiumNitrate')
     append_single_phase_chemical('Oil', 'Oleic acid')
-    append_single_phase_chemical('HMF')
+    append_single_phase_chemical('HMF', 'Hydroxymethylfurfural', phase='l')
     
     # Will remain in the vapor phase
     extend_single_phase_chemicals(['N2', 'O2', 'CH4', 'H2S', 'SO2'])
@@ -219,9 +219,7 @@ def create_chemicals():
     append_new_single_phase_chemical('Cellobiose', formula="C12H22O11",
                                      Hf=-480900*cal2joule)
     append_new_single_phase_chemical('CSL', 
-                                     MW=(chems.Protein.MW / 4 
-                                         + chems.Water.MW / 2  
-                                         + chems.LacticAcid.MW / 4),
+                                     formula='H2.8925O1.3275C1N0.0725S0.00175',
                                      Hf=(chems.Protein.Hf/4
                                          + chems.Water.Hf/2
                                          + chems.LacticAcid.Hf/4))
