@@ -23,9 +23,12 @@ __all__ = (
     'create_facilities',
     'create_hot_water_pretreatment_system',
     'create_dilute_acid_pretreatment_system',
-    'create_continuous_saccharification_system',
-    'create_saccharification_and_cofermentation_system',
+    'create_saccharification_system',
+    'create_cofermentation_system',
+    'create_simultaneous_saccharification_and_cofermentation_system',
+    'create_integrated_bioprocess_saccharification_and_cofermentation_system',
     'create_cellulosic_fermentation_system',
+    'create_ammonia_fiber_expansion_pretreatment_system',
 )
 
 default_nonsolids = ['Water', 'Ethanol', 'AceticAcid', 
@@ -34,26 +37,30 @@ default_nonsolids = ['Water', 'Ethanol', 'AceticAcid',
 default_insoluble_solids = ['Glucan', 'Mannan', 'Xylan', 
                             'Arabinan', 'Galactan', 'Lignin']
 
-default_ignored = ['Lipid']
+default_ignored = ['TAG', 'DAG', 'MAG', 'FFA', 'PL']
+
+cornstover_dct = dict(
+    ID='cornstover', # Cornstover composition by default
+    Glucan=0.28,
+    Xylan=0.1562,
+    Galactan=0.001144,
+    Arabinan=0.01904,
+    Mannan=0.0048,
+    Lignin=0.12608,
+    Acetate=0.01448,
+    Protein=0.0248,
+    Extract=0.1172,
+    Ash=0.03944,
+    Sucrose=0.00616,
+    Water=0.2,
+    total_flow=104229.16,
+    units='kg/hr',
+    price=price['Feedstock']
+)
 
 @bst.SystemFactory(
     ID='hot_water_pretreatment_sys',
-    ins=[dict(ID='cornstover', # Cornstover composition by default
-              Glucan=0.28,
-              Xylan=0.1562,
-              Galactan=0.001144,
-              Arabinan=0.01904,
-              Mannan=0.0048,
-              Lignin=0.12608,
-              Acetate=0.01448,
-              Protein=0.0248,
-              Extract=0.1172,
-              Ash=0.03944,
-              Sucrose=0.00616,
-              Water=0.2,
-              total_flow=104229.16,
-              units='kg/hr',
-              price=price['Feedstock'])],
+    ins=[cornstover_dct],
     outs=[dict(ID='hydrolyzate'),
           dict(ID='pretreatment_wastewater')],
 )
@@ -63,6 +70,8 @@ def create_hot_water_pretreatment_system(
         include_feedstock_handling=True,
         solids_loading=0.305,
         nonsolids=['Water'],
+        milling=False,
+        T_pretreatment_reactor=273.15 + 130.
     ):
     
     feedstock, = ins
@@ -81,45 +90,125 @@ def create_hot_water_pretreatment_system(
     
     ### Pretreatment system
     n = pretreatment_area
-    M203 = bst.SteamMixer(f'M{n+2}', (feedstock, pretreatment_steam, warm_process_water), P=5.5*101325)
-    R201 = units.PretreatmentReactorSystem(f'R{n+1}', M203-0)
+    P = pretreatment_steam.chemicals['H2O'].Psat(T_pretreatment_reactor + 25)
+    M203 = bst.SteamMixer(f'M{n+2}', (feedstock, pretreatment_steam, warm_process_water),
+                          P=P, solids_loading=solids_loading)
+    R201 = units.PretreatmentReactorSystem(f'R{n+1}', M203-0, T=T_pretreatment_reactor)
     P201 = units.BlowdownDischargePump(f'P{n+1}', R201-1)
-    T202 = units.OligomerConversionTank(f'T{n+2}', P201-0)
-    F201 = units.PretreatmentFlash(f'F{n+1}', T202-0, P=101325, Q=0)
+    F201 = units.PretreatmentFlash(f'F{n+1}', P201-0, P=101325, Q=0)
     M204 = bst.Mixer(f'M{n+3}', (R201-0, F201-0))
     H201 = units.WasteVaporCondenser(f'H{n+1}', M204-0, pretreatment_wastewater, V=0)
-    P202 = units.HydrolyzatePump(f'P{n+2}', F201-1, hydrolyzate)
-    
-    chemicals = M203.chemicals
-    M203.solids_loading = solids_loading
-    indices = chemicals.available_indices(nonsolids)
-    @M203.add_specification(run=True)
-    def update_pretreatment_process_water():
-        solids_loading = M203.solids_loading
-        *other_feeds, warm_process_water = M203.ins
-        F_mass_feed = sum([i.F_mass for i in other_feeds if i])
-        available_water = (chemicals.MW[indices] * sum([i.mol[indices] for i in other_feeds if i])).sum()
-        required_water = (F_mass_feed - available_water) * (1. - solids_loading) / solids_loading
-        warm_process_water.imass['Water'] = max(required_water - available_water, 0.)
+    P202 = units.HydrolyzatePump(f'P{n+2}', F201-1, None)
+    if milling:
+        U201 = bst.HammerMill(f'U{n+1}', P202-0, hydrolyzate)
+        P202.outs[0].materialize_connection
+    else:
+        P202.outs[0] = hydrolyzate
 
 @bst.SystemFactory(
-    ID='dilute_acid_pretreatment_sys',
-    ins=[dict(ID='cornstover', # Cornstover composition by default
-              Glucan=0.28,
-              Xylan=0.1562,
-              Galactan=0.001144,
-              Arabinan=0.01904,
-              Mannan=0.0048,
-              Lignin=0.12608,
-              Acetate=0.01448,
-              Protein=0.0248,
-              Extract=0.1172,
-              Ash=0.03944,
-              Sucrose=0.00616,
+    ID='AFEX_pretreatment_sys',
+    ins=[dict(ID='switchgrass', # Switchgrass composition by default
+              Arabinan=0.02789023841655421,
+              Galactan=0.010436347278452543,
+              Glucan=0.2717049032838507,
+              Xylan=0.21214574898785432,
+              Mannan=0.005937921727395412,
+              Lignin=0.17112010796221322,
+              Ash=0.016194331983805668,
+              Extractives=0.08457040035987407,
               Water=0.2,
               total_flow=104229.16,
               units='kg/hr',
-              price=price['Feedstock'])],
+              price=0.08)], # Price of switchgrass, table 4, Madhu Khanna et al. (Costs of producing miscanthus and switchgrass for bioenergy in Illinois);  https://www.sciencedirect.com/science/article/pii/S096195340700205X?casa_token=KfYfzJtDwv0AAAAA:OqeJmpofk1kIgFk2DcUvXNG35qYwlWvPKZ7ENI3R6RUKeoahiTDpOhhd_mpLtRthTGuXJKDzMOc
+    outs=[dict(ID='pretreated_biomass'),],
+)
+def create_ammonia_fiber_expansion_pretreatment_system(
+        ins, outs,
+        include_feedstock_handling=True,
+        solids_loading=0.20,
+        ammonia_loading=2, # g ammonia / g dry feedstock
+        T_pretreatment_reactor=273.15 + 100.,
+        residence_time=0.5,
+        pretreatment_reactions=None,
+    ):
+    
+    feedstock, = ins
+    hydrolyzate, = outs
+    
+    ammonia = Stream('ammonia', NH3=1, P=12 * 101325, price=price['Ammonia'])
+    sulfuric_acid = Stream('sulfuric_acid',
+                            P=5.4*101325,
+                            T=294.15,
+                            Water=130,
+                            H2SO4=1800,
+                            units='kg/hr',
+                            price=price['Sulfuric acid'])
+    warm_process_water = Stream('warm_process_water',
+                              T=368.15,
+                              P=4.7*101325,
+                              Water=1)
+    pretreatment_steam = Stream('pretreatment_steam',
+                    phase='g',
+                    T=268+273.15,
+                    P=13*101325,
+                    Water=24534+3490,
+                    units='kg/hr')
+    air = bst.Stream('air', O2=0.23, N2=0.77, phase='g', units='kg/hr')
+    
+    ### Pretreatment system
+    ideal = ammonia.thermo.ideal()
+    T201 = bst.StorageTank('T201', ammonia, tau=7, thermo=ideal)
+    T201.ammonia_loading = ammonia_loading
+    recycle = bst.Stream()
+    P = pretreatment_steam.chemicals['H2O'].Psat(T_pretreatment_reactor + 25)
+    M202 = bst.SteamMixer('M202', (feedstock, pretreatment_steam, warm_process_water, recycle), 
+                          liquid_IDs=['Water', 'NH3'], P=P, solids_loading=solids_loading, thermo=ideal)
+    R201 = units.PretreatmentReactorSystem('R201', M202-0, tau=residence_time,
+                                           T=T_pretreatment_reactor, thermo=ideal,
+                                           reactions=pretreatment_reactions,
+                                           run_vle=False)
+    P201 = units.BlowdownDischargePump('P201', R201-1, thermo=ideal)
+    M205 = bst.Mixer('M205', (P201-0, air))
+    F201 = bst.Flash('F201', M205-0, P=101325, T=310, thermo=ideal)
+    @M205.add_specification(run=True)
+    def update_air():
+        feed, air = M205.ins
+        flow = 100 * feed.F_vol
+        air.imol['O2', 'N2'] = [flow * 0.23, flow * 0.77] # Assume equal volumes is enough
+    
+    M204 = bst.Mixer('M204', (R201-0, F201-0), thermo=ideal)
+    F202 = bst.Flash('F202', M204-0, V=0, P=101325, thermo=ideal)
+    P203 = bst.Pump('P203', F202-1, P=10*101325)
+    M206 = bst.Mixer('M206', (P203-0, T201-0), recycle)
+    
+    @M206.add_specification(run=True)
+    def adjust_ammonia():
+        recycle = M206.ins[0]
+        fresh_ammonia = T201.ins[0]
+        fresh_ammonia.imass['NH3'] = NH3_loss = F202.outs[0].imass['NH3'] + F201.outs[1].imass['NH3']
+        required_ammonia = T201.ammonia_loading * (feedstock.F_mass - feedstock.imass['Water'])
+        recycle.imass['NH3'] = required_ammonia - NH3_loss
+        for i in T201.path_until(M206): i.run()
+    
+    P202 = units.HydrolyzatePump('P202', F201-1, thermo=ideal)
+    H2SO4_storage = units.SulfuricAcidStorageTank('H2SO4_storage', sulfuric_acid)
+    T202 = units.SulfuricAcidTank('T202', H2SO4_storage-0)
+    M207 = bst.Mixer('M207', (T202-0, P202-0), hydrolyzate)
+    
+    M207.neutralization_rxn = tmo.Reaction('2 NH3 + H2SO4 -> (NH4)2SO4', 'H2SO4', 1)
+    @M207.add_specification
+    def update_sulfuric_acid_loading():
+        _, feed = M207.ins
+        fresh_sulfuric_acid = H2SO4_storage.ins[0]
+        fresh_sulfuric_acid.imol['H2SO4'] = feed.imol['NH3'] / 2
+        for i in H2SO4_storage.path_until(M207): i.run()
+        M207._run()
+        M207.neutralization_rxn(M207.outs[0])
+    
+
+@bst.SystemFactory(
+    ID='dilute_acid_pretreatment_sys',
+    ins=[cornstover_dct],
     outs=[dict(ID='hydrolyzate'),
           dict(ID='pretreatment_wastewater')],
 )
@@ -166,8 +255,8 @@ def create_dilute_acid_pretreatment_system(
     H2SO4_storage = units.SulfuricAcidStorageTank('H2SO4_storage', sulfuric_acid)
     T201 = units.SulfuricAcidTank(f'T{n+1}', H2SO4_storage-0)
     M201 = units.SulfuricAcidMixer(f'M{n+1}', (warm_process_water_1, T201-0))
-    M202 = bst.Mixer(f'M{n+2}', (M201-0, warm_process_water_2, feedstock))
-    M203 = bst.SteamMixer(f'M{n+3}', (M202-0, pretreatment_steam), P=5.5*101325)
+    M203 = bst.SteamMixer(f'M{n+3}', (feedstock, pretreatment_steam, warm_process_water_2, M201-0),
+                          P=5.5*101325, solids_loading=solids_loading)
     R201 = units.PretreatmentReactorSystem(f'R{n+1}', M203-0)
     P201 = units.BlowdownDischargePump(f'P{n+1}', R201-1)
     T202 = units.OligomerConversionTank(f'T{n+2}', P201-0)
@@ -179,17 +268,6 @@ def create_dilute_acid_pretreatment_system(
     T203 = units.AmmoniaAdditionTank(f'T{n+3}', (F201-1, M205-0))
     P202 = units.HydrolyzatePump(f'P{n+2}', T203-0, hydrolyzate)
     
-    M202.solids_loading = solids_loading
-    chemicals  = M202.chemicals 
-    indices = chemicals.available_indices(default_nonsolids)
-    @M202.add_specification(run=True)
-    def update_pretreatment_process_water():
-        sulfuric_acid, warm_process_water, feed = M202.ins
-        available_water = (chemicals.MW[indices] * (feed.mol[indices] + sulfuric_acid.mol[indices])).sum()
-        solids_loading = M202.solids_loading
-        required_water = (feed.F_mass + sulfuric_acid.F_mass - available_water) * (1. - solids_loading) / solids_loading
-        warm_process_water.imass['Water'] = max(required_water - available_water, 0.)
-    
     @T201.add_specification(run=True)
     def update_sulfuric_acid_loading():
         F_mass_dry_feedstock = feedstock.F_mass - feedstock.imass['water']
@@ -219,12 +297,14 @@ def create_dilute_acid_pretreatment_system(
          dict(ID='saccharification_water')],
     outs=[dict(ID='slurry')],
 )
-def create_continuous_saccharification_system(
+def create_saccharification_system(
         ins, outs, solids_loading=None, 
         nonsolids=None,
         insoluble_solids=None,
         insoluble_solids_loading=None,
         ignored=None,
+        Saccharification=None,
+        saccharification_reactions=None,
     ):
     hydrolyzate, cellulase, saccharification_water = ins
     slurry, = outs
@@ -237,25 +317,30 @@ def create_continuous_saccharification_system(
     H301 = units.HydrolysateHeatExchanger('H301', M301-0, T=48+273.15)
     M301.solids_loading = solids_loading
     M301.insoluble_solids_loading = insoluble_solids_loading
-    enzyme_over_cellulose = 0.4 # (20 g enzyme / 1000 g cellulose) / (50 g cellulase / 1000g enzyme)
-    z_mass_cellulase_mixture = np.array([0.95, 0.05])
+    M301.enzyme_loading = 0.02 # (20 g enzyme / 1000 g cellulose mixture) 
+    M301.enzyme_concentration = 0.05 # (50 g cellulase / 1000g cellulose) 
+    
     @M301.add_specification
     def update_cellulase_loading():
         hydrolyzate, cellulase, water = M301.ins
-        # Note: An additional 10% is produced for the media glucose/sophorose mixture
+        # Note: An additional 10% is produced to produce sophorose
         # Humbird (2011) pg. 37 
+        enzyme_concentration = M301.enzyme_concentration
+        enzyme_over_cellulose = M301.enzyme_loading / enzyme_concentration
+        z_mass_cellulase_mixture = np.array([1 - enzyme_concentration , enzyme_concentration], float)
         cellulase.imass['Water', 'Cellulase'] = (
             enzyme_over_cellulose
             * z_mass_cellulase_mixture
-            * 1.1 * (hydrolyzate.imass['Glucan', 'GlucoseOligomer'].sum() * 1.1)
+            * 1.2 * (hydrolyzate.imass['Glucan'])
         )
     
-    chemicals = M301.chemicals
     
     @M301.add_specification(run=True)
     def update_moisture_content():
         hydrolyzate, cellulase, saccharification_water, *other = M301.ins
-        mass = chemicals.MW * sum([i.mol for i in [hydrolyzate, cellulase] + other]) 
+        chemicals = M301.chemicals
+        s_mix = Stream.sum([hydrolyzate, cellulase], None, M301.outs[0].thermo, energy_balance=False)
+        mass = s_mix.mol * chemicals.MW
         solids_loading = M301.solids_loading
         insoluble_solids_loading = M301.insoluble_solids_loading
         indices = chemicals.available_indices(nonsolids)
@@ -276,7 +361,9 @@ def create_continuous_saccharification_system(
         )
         saccharification_water.imass['Water'] = max(M301.required_saccharification_water, 0.)
     
-    R301 = units.ContinuousPresaccharification('R301', H301-0, slurry)
+    if Saccharification is None:
+        Saccharification = units.ContinuousPresaccharification
+    R301 = Saccharification('R301', H301-0, slurry, reactions=saccharification_reactions)
 
 @bst.SystemFactory(
     ID='cofermentation_sys',
@@ -290,6 +377,9 @@ def create_continuous_saccharification_system(
 )
 def create_simultaneous_saccharification_and_cofermentation_system(
         ins, outs, SimultaneousSaccharificationAndCoFermentation=None, SeedTrain=None,
+        saccharification_reactions=None,
+        seed_train_reactions=None,
+        cofermentaion_reactions=None,
         include_scrubber=True
     ):
     slurry, DAP, CSL = ins
@@ -320,26 +410,32 @@ def create_simultaneous_saccharification_and_cofermentation_system(
     if not SimultaneousSaccharificationAndCoFermentation:
         SimultaneousSaccharificationAndCoFermentation = units.SimultaneousSaccharificationAndCoFermentation
     if not SeedTrain: SeedTrain = units.SeedTrain
-    R302 = SeedTrain('R302', (S303-0, CSL1, DAP1), saccharification=True)
+    R302 = SeedTrain('R302', (S303-0, CSL1, DAP1), 
+                     reactions=seed_train_reactions,
+                     saccharification=saccharification_reactions or True)
     
     def adjust_CSL_and_DAP_feed_to_seed_train():
         feed, CSL1, DAP1 = R302.ins
         CSL1.imass['CSL'] = 0.0050 * feed.F_mass
         DAP1.imass['DAP'] = 0.33 * feed.F_vol
-        S301.ins[0].mix_from(S301.outs)
         R302._run()
     
     R302.specification = adjust_CSL_and_DAP_feed_to_seed_train
     T301 = units.SeedHoldTank('T301', R302-1)
     R303 = SimultaneousSaccharificationAndCoFermentation(
-        'R303', (S303-1, T301-0, CSL2, DAP2),
+        'R303', (S303-1, T301-0, CSL2, DAP2), 
+        saccharification=saccharification_reactions,
+        cofermentaion=cofermentaion_reactions,
     )
     
     def adjust_CSL_and_DAP_feed_to_fermentation():
         feed, seed, CSL2, DAP2 = R303.ins
         CSL2.imass['CSL'] = 0.0025 * feed.F_mass
         DAP2.imass['DAP'] = 0.33 * feed.F_vol
+        S301.ins[0].mix_from(S301.outs)
         S302.ins[0].mix_from(S302.outs)
+        DAP_storage.ins[0].copy_like(DAP_storage.outs[0])
+        CSL_storage.ins[0].copy_like(CSL_storage.outs[0])
         R303._run()
     
     R303.specification = adjust_CSL_and_DAP_feed_to_fermentation
@@ -375,8 +471,11 @@ def create_simultaneous_saccharification_and_cofermentation_system(
     outs=[dict(ID='vent'),
           dict(ID='beer')],
 )
-def create_saccharification_and_cofermentation_system(
+def create_integrated_bioprocess_saccharification_and_cofermentation_system(
         ins, outs, SaccharificationAndCoFermentation=None, SeedTrain=None,
+        saccharification_reactions=None,
+        seed_train_reactions=None,
+        cofermentation_reactions=None,
         include_scrubber=True
     ):
     slurry, DAP, CSL = ins
@@ -407,25 +506,31 @@ def create_saccharification_and_cofermentation_system(
         SaccharificationAndCoFermentation = units.SaccharificationAndCoFermentation
     if not SeedTrain: SeedTrain = units.SeedTrain
     recycle = bst.Stream()
-    R302 = SeedTrain('R302', (recycle, CSL1, DAP1))
+    R302 = SeedTrain('R302', (recycle, CSL1, DAP1), 
+                     reactions=seed_train_reactions)
     
     def adjust_CSL_and_DAP_feed_to_seed_train():
         feed, CSL1, DAP1 = R302.ins
         CSL1.imass['CSL'] = 0.0050 * feed.F_mass
         DAP1.imass['DAP'] = 0.33 * feed.F_vol
-        S301.ins[0].mix_from(S301.outs)
         R302._run()
     
     R302.specification = adjust_CSL_and_DAP_feed_to_seed_train
     T301 = units.SeedHoldTank('T301', R302-1)
-    R303 = SaccharificationAndCoFermentation('R303', (slurry, T301-0, CSL2, DAP2),
-                                             outs=('', '', recycle))
+    R303 = SaccharificationAndCoFermentation(
+        'R303', (slurry, T301-0, CSL2, DAP2), outs=('', '', recycle), 
+        cofermentation=cofermentation_reactions,
+        saccharification=saccharification_reactions,
+    )
     
     def adjust_CSL_and_DAP_feed_to_fermentation():
         feed, seed, CSL2, DAP2 = R303.ins
         CSL2.imass['CSL'] = 0.0025 * feed.F_mass
         DAP2.imass['DAP'] = 0.33 * feed.F_vol
+        S301.ins[0].mix_from(S301.outs)
         S302.ins[0].mix_from(S302.outs)
+        DAP_storage.ins[0].copy_like(DAP_storage.outs[0])
+        CSL_storage.ins[0].copy_like(CSL_storage.outs[0])
         R303._run()
     
     R303.specification = adjust_CSL_and_DAP_feed_to_fermentation
@@ -451,6 +556,95 @@ def create_saccharification_and_cofermentation_system(
         M304.outs[0] = vent
         R303-1-T302
  
+@bst.SystemFactory(
+    ID='cofermentation_sys',
+    ins=[dict(ID='slurry'),
+         dict(ID='DAP',
+              price=price['DAP']),
+         dict(ID='CSL',
+              price=price['CSL'])],
+    outs=[dict(ID='vent'),
+          dict(ID='beer'),
+          dict(ID='lignin')],
+)
+def create_cofermentation_system(
+        ins, outs, CoFermentation=None, SeedTrain=None,
+        include_scrubber=True,
+        seed_train_reactions=None,
+        cofermentation_reactions=None,
+    ):
+    slurry, DAP, CSL = ins
+    vent, beer, lignin = outs
+    
+    DAP1 = Stream('DAP1',
+                    DAP=26,
+                    units='kg/hr',
+                    price=price['DAP'])
+    DAP2 = Stream('DAP2',
+                    DAP=116,
+                    units='kg/hr',
+                    price=price['DAP'])
+    CSL1 = Stream('CSL1',
+                    CSL=211,
+                    units='kg/hr',
+                    price=price['CSL'])
+    CSL2 = Stream('CSL2',
+                    CSL=948,
+                    units='kg/hr',
+                    price=price['CSL'])
+    
+    DAP_storage = units.DAPStorageTank('DAP_storage', DAP)
+    S301 = bst.FakeSplitter('S301', DAP_storage-0, outs=(DAP1, DAP2))
+    CSL_storage = units.CSLStorageTank('CSL_storage', CSL)
+    S302 = bst.FakeSplitter('S302', CSL_storage-0, outs=(CSL1, CSL2))
+    S303 = bst.PressureFilter('S303', slurry, (lignin, ''))
+    S304 = bst.Splitter('S304', S303-1, split=0.1)
+    if not SeedTrain: SeedTrain = units.SeedTrain
+    R302 = SeedTrain('R302', (S304-0, CSL1, DAP1), reactions=seed_train_reactions)
+    
+    @R302.add_specification(run=True)
+    def adjust_CSL_and_DAP_feed_to_seed_train():
+        feed, CSL1, DAP1 = R302.ins
+        CSL1.imass['CSL'] = 0.0050 * feed.F_mass
+        DAP1.imass['DAP'] = 0.33 * feed.F_vol
+    
+    T301 = units.SeedHoldTank('T301', R302-1)
+    if not CoFermentation: CoFermentation = units.CoFermentation
+    R303 = CoFermentation('R303', (S304-1, T301-0, CSL2, DAP2),
+                          outs=('', ''), cofermentation=cofermentation_reactions)
+    
+    @R303.add_specification(run=True)
+    def adjust_CSL_and_DAP_feed_to_fermentation():
+        feed, seed, CSL2, DAP2, *other = R303.ins
+        CSL2.imass['CSL'] = 0.0025 * feed.F_mass
+        DAP2.imass['DAP'] = 0.33 * feed.F_vol
+        S301.ins[0].mix_from(S301.outs)
+        S302.ins[0].mix_from(S302.outs)
+        DAP_storage.ins[0].copy_like(DAP_storage.outs[0])
+        CSL_storage.ins[0].copy_like(CSL_storage.outs[0])
+    
+    M304 = bst.Mixer('M304', (R302-0, R303-0))
+    T302 = units.BeerTank('T302', outs=beer)
+    
+    if include_scrubber:
+        stripping_water = Stream('stripping_water',
+                                 Water=26836,
+                                 units='kg/hr')
+        M401 = bst.Mixer('M401', (R303-1, None))
+        D401 = bst.VentScrubber('D401', (stripping_water, M304-0), (vent, ''),
+                                gas=('CO2', 'NH3', 'O2'))
+        D401-1-1-M401-0-T302
+    
+        stripping_water_over_vent = stripping_water.imol['Water'] / 21202.490455845436
+        def update_stripping_water():
+            stripping_water, vent = D401.ins
+            stripping_water.imol['Water'] = stripping_water_over_vent * vent.F_mass
+            D401._run()
+        D401.specification = update_stripping_water
+    else:
+        M304.outs[0] = vent
+        R303-1-T302   
+ 
 @bst.SystemFactory(
     ID='cellulosic_fermentation_sys',
     ins=[dict(ID='hydrolyzate'),
@@ -463,7 +657,9 @@ def create_saccharification_and_cofermentation_system(
          dict(ID='CSL',
               price=price['CSL'])],
     outs=[dict(ID='vent'),
-          dict(ID='beer')],
+          dict(ID='beer'),
+          dict(ID='lignin')],
+    optional_outs_index=[2],
 )
 def create_cellulosic_fermentation_system(
         ins, outs,
@@ -475,29 +671,60 @@ def create_cellulosic_fermentation_system(
         kind=0, 
         # 0 for Integrated Bioprocess(IB)
         # 1 for Simultaneous Saccharification and Co-fermentation (SSCF) 
+        # 2 for Saccharification and Co-fermentation (SCF)
+        Saccharification=None,
+        ContinuousPresaccharification=None,
+        SeedTrain=None,
+        CoFermentation=None,
+        SaccharificationAndCoFermentation=None,
+        saccharification_reactions=None,
+        seed_train_reactions=None,
+        cofermentation_reactions=None,
     ):
-    vent, beer = outs
+    vent, beer, lignin = outs
     hydrolyzate, cellulase, saccharification_water, DAP, CSL = ins
     
-    saccharification_sys = create_continuous_saccharification_system(
+    saccharification_sys = create_saccharification_system(
         ins=[hydrolyzate, cellulase, saccharification_water],
         mockup=True,
         solids_loading=solids_loading,
         insoluble_solids_loading=insoluble_solids_loading,
         nonsolids=nonsolids,
         insoluble_solids=insoluble_solids,
+        Saccharification=(Saccharification or units.Saccharification if kind == 2 else ContinuousPresaccharification or units.ContinuousPresaccharification),
+        saccharification_reactions=saccharification_reactions,
     )
     if kind == 0:
-        cofermentation_sys = create_saccharification_and_cofermentation_system(
+        cofermentation_sys = create_integrated_bioprocess_saccharification_and_cofermentation_system(
             ins=[saccharification_sys-0, DAP, CSL],
             outs=[vent, beer],
-            mockup=True
+            mockup=True,
+            SaccharificationAndCoFermentation=SaccharificationAndCoFermentation,
+            SeedTrain=SeedTrain,
+            include_scrubber=include_scrubber,
+            seed_train_reactions=seed_train_reactions,
+            cofermentation_reactions=cofermentation_reactions,
         )
     elif kind == 1:
         cofermentation_sys = create_simultaneous_saccharification_and_cofermentation_system(
             ins=[saccharification_sys-0, DAP, CSL],
             outs=[vent, beer],
-            mockup=True
+            mockup=True,
+            include_scrubber=include_scrubber,
+            seed_train_reactions=seed_train_reactions,
+            cofermentation_reactions=cofermentation_reactions,
+        )
+    elif kind == 2:
+        T303 = bst.StorageTank('T303', saccharification_sys-0, tau=4)
+        cofermentation_sys = create_cofermentation_system(
+            ins=[T303-0, DAP, CSL],
+            outs=[vent, beer, lignin],
+            mockup=True,
+            SeedTrain=SeedTrain,
+            CoFermentation=CoFermentation,
+            include_scrubber=include_scrubber,
+            seed_train_reactions=seed_train_reactions,
+            cofermentation_reactions=cofermentation_reactions,
         )
     else:
         raise ValueError("invalid 'kind'")
