@@ -39,7 +39,7 @@ def create_bagasse_pelleting_system(ins, outs):
     U402 = units.DrumDryer('U402', 
         (U401-0, 'dryer_air', 'dryer_natural_gas'), 
         ('', 'dryer_outlet_air', 'dryer_emissions'),
-        moisture_content=0.15, split=0.,
+        moisture_content=0.18, split=0.,
     )
     # X401 = bst.ThermalOxidizer('X401', (U403-1, 'oxidizer_air'), 'oxidizer_emissions')
     U403 = units.ScrewFeeder('U403', U402-0)
@@ -71,38 +71,24 @@ def create_feedstock_handling_system(ins, outs):
 
 @SystemFactory(
     ID='juicing_sys',
-    ins=[create_feedstock_handling_system.ins[0],
-         dict(ID='enzyme',
-              Cellulose=100,
-              Water=900,
-              units='kg/hr',
-              price=0.5),],
+    ins=[create_feedstock_handling_system.ins[0]],
     outs=[dict(ID='untreated_juice'),
           dict(ID='bagasse')]
 )
 def create_juicing_system_without_treatment(ins, outs, pellet_bagasse=None):
-    if pellet_bagasse is None: pellet_bagasse = True
+    if pellet_bagasse is None: pellet_bagasse = False
     
     ### Streams ###
-    sugarcane, enzyme = ins
+    sugarcane, = ins
     untreated_juice, bagasse = outs
     
     imbibition_water = bst.Stream('imbibition_water',
                                   Water=87023.35, units='kg/hr',
                                   T = 350.15)
     
-    # Hydrolyze starch
-    T201 = units.EnzymeTreatment('T201', (sugarcane, enzyme), T=323.15)  # T=50
-    
-    @T201.add_specification(run=True)
-    def update_enzyme_and_imbibition_water():
-        F_mass = T201.ins[0].F_mass
-        enzyme.imass['Cellulose', 'Water'] = 0.003 * F_mass * np.array([0.1, 0.9])
-        imbibition_water.imass['Water'] = 0.25 * F_mass
-    
     # Finely crush lipid cane
     U201 = units.CrushingMill('U201',
-                              ins=(T201-0, ''),
+                              ins=(sugarcane, ''),
                               split=dict(Ash=0.92,
                                          Cellulose=0.92,
                                          Glucose=0.04,
@@ -111,6 +97,11 @@ def create_juicing_system_without_treatment(ins, outs, pellet_bagasse=None):
                                          Sucrose=0.04,
                                          Solids=1),
                               moisture_content=0.5)
+    
+    @U201.add_specification(run=True)
+    def update_imbibition_water():
+        imbibition_water.imass['Water'] = 0.245 * U201.ins[0].F_mass
+    
     U202 = units.ConveyingBelt('U202', U201-0, [''] if pellet_bagasse else [bagasse])
     
     if pellet_bagasse:
@@ -158,7 +149,7 @@ def create_juicing_system_without_treatment(ins, outs, pellet_bagasse=None):
 def create_juicing_system_up_to_clarification(ins, outs, pellet_bagasse=None):
     
     ### Streams ###
-    sugarcane, enzyme, H3PO4, lime, polymer = ins
+    sugarcane, H3PO4, lime, polymer = ins
     clarified_juice, bagasse = outs
     
     rvf_wash_water = bst.Stream('rvf_wash_water',
@@ -166,12 +157,12 @@ def create_juicing_system_up_to_clarification(ins, outs, pellet_bagasse=None):
                                 T=363.15)  # to C202
     
     juicing_sys_without_treatment = create_juicing_system_without_treatment(
-        ins=(sugarcane, enzyme),
+        ins=(sugarcane,),
         outs=('', bagasse),
         mockup=True,
         pellet_bagasse=pellet_bagasse,
     )
-    T201 = f.unit.T201
+    U201 = f.unit.U201
     
     # Heat up before adding acid
     H201 = units.HXutility('H201', juicing_sys_without_treatment-0, T=343.15)
@@ -227,14 +218,12 @@ def create_juicing_system_up_to_clarification(ins, outs, pellet_bagasse=None):
     ### Process specifications ###
     
     # Specifications dependent on lipid cane flow rate
-    @T201.add_specification(run=True)
+    @U201.add_specification(run=True)
     def correct_flows():
-        F_mass = T201.ins[0].F_mass
-        # correct enzyme, lime, phosphoric acid, and imbibition water
-        enzyme.F_mass *= F_mass / 333334.2
+        F_mass = U201.ins[0].F_mass
+        # correct lime, phosphoric acid, and imbibition water
         lime.imass['CaO', 'Water'] = 0.001 * F_mass * np.array([0.046, 0.954])
         H3PO4.imass['H3PO4', 'Water'] = 0.00025 * F_mass
-        T201._run()
     
     # Specifications within a system
     def correct_wash_water():
@@ -296,7 +285,7 @@ def create_beer_distillation_system(ins, outs,
     beer, = ins
     distilled_beer, stillage = outs
     
-    P301 = units.Pump(IDs.get('Beer pump', 'P301'))
+    P301 = units.Pump(IDs.get('Beer pump', 'P301'), P=2. * 101325)
     
     # Beer column
     x_bot = 3.91e-06
@@ -308,7 +297,7 @@ def create_beer_distillation_system(ins, outs,
     D302.tray_material = 'Stainless steel 304'
     D302.vessel_material = 'Stainless steel 304'
     D302.boiler.U = 1.85
-    P302 = units.Pump(IDs.get('Beer column bottoms product pump', 'P302'))
+    P302 = units.Pump(IDs.get('Beer column bottoms product pump', 'P302'), P=101325.)
     
     # Heat up before beer column
     # Exchange heat with stillage    
@@ -354,7 +343,7 @@ def create_ethanol_purification_system_after_beer_column(ins, outs, IDs={}):
     
     # Superheat vapor for mol sieve
     H303 = units.HXutility(IDs.get('Heat exchanger to superheat vapor to molecular sieves', 'H303'),
-                           T=115+273.15, V=1)
+                           T=115+273.15, V=1, heat_only=True)
     
     # Molecular sieve
     U301 = units.MolecularSieve(IDs.get('Molecular sieves', 'U301'),
@@ -384,13 +373,14 @@ def create_ethanol_purification_system_after_beer_column(ins, outs, IDs={}):
     ### Ethanol system set-up ###
     (distilled_beer, U301-0)-M303-0-D303-0-H303-U301
     D303-1-P303
+    M304.denaturant_fraction = 0.022
     
+    @M304.add_specification(run=True)
     def adjust_denaturant():
-        P304._run()
-        pure_ethanol = P304.outs[0]
-        denaturant.imol['Octane'] = 0.022*pure_ethanol.F_mass/114.232
+        pure_ethanol = M304.ins[1]
+        denaturant.imol['Octane'] = M304.denaturant_fraction * pure_ethanol.F_mass / 114.232
+        for i in T303.path_until(M304): i._run()
     
-    P304.specification = adjust_denaturant
     (denaturant-T303-P305-0, U301-1-H304-0-T302-0-P304-0)-M304-T304
 
 # @SystemFactory(
@@ -523,15 +513,13 @@ def create_sucrose_fermentation_system(ins, outs, scrubber=True):
     
     def sugar_concentration_at_fraction_evaporated(V):
         F301.V = V
-        F301._run()
-        P306._run()
+        for i in F301.path_until(M301): i._run()
         M301._run()
         return F301.sugar_concentration - get_sugar_concentration()
     
     def get_dilution_water():
         F301.V = 0
-        F301._run()
-        P306._run()
+        for i in F301.path_until(M301): i._run()
         M301._run()
         target = F301.sugar_concentration
         current = get_sugar_concentration()
@@ -544,7 +532,6 @@ def create_sucrose_fermentation_system(ins, outs, scrubber=True):
         s_dilution_water.empty()
         dilution_water = get_dilution_water()
         if dilution_water < 0.:
-            y0 = sugar_concentration_at_fraction_evaporated(0.)
             y1 = sugar_concentration_at_fraction_evaporated(1.)
             if y1 > 0.: 
                 S301.split = 0.05
@@ -555,7 +542,6 @@ def create_sucrose_fermentation_system(ins, outs, scrubber=True):
                     S301._run()
                     y1 = sugar_concentration_at_fraction_evaporated(1.)
                     if y1 > 0.:
-                        breakpoint()
                         raise RuntimeError('cannot evaporate to target sugar concentration')
             F301.V = flx.IQ_interpolation(
                 sugar_concentration_at_fraction_evaporated,
@@ -613,7 +599,8 @@ def create_sucrose_fermentation_system(ins, outs, scrubber=True):
         yeast = 0.1 * feed.F_mass
         m = C301.moisture_content
         recycle.imass['Yeast', 'Water'] = [yeast, yeast * m / (1 - m)]
-        beer.mol = feed.mol - recycle.mol
+        beer.copy_like(feed)
+        beer.separate_out(recycle, energy_balance=False)
         beer.mol[beer.mol < 0.] = 0.
         beer.T = recycle.T = feed.T
     S302.specification = adjust_yeast_recycle
@@ -664,39 +651,47 @@ def create_sucrose_to_ethanol_system(ins, outs):
           dict(ID='emissions'),
           dict(ID='ash_disposal')]
 )
-def create_sugarcane_to_ethanol_system(ins, outs):
+def create_sugarcane_to_ethanol_system(ins, outs, 
+                                       use_area_convention=False,
+                                       pellet_bagasse=None):
     s = f.stream
     u = f.unit
     
-    sugarcane, enzyme, H3PO4, lime, polymer, denaturant = ins
+    sugarcane, H3PO4, lime, polymer, denaturant = ins
     ethanol, vinasse, wastewater, emissions, ash_disposal = outs
     
     feedstock_handling_sys = create_feedstock_handling_system(
+        area=100 if use_area_convention else None,
         ins=[sugarcane],
         outs=[''],
+        mockup=True,
     )
     juicing_sys = create_juicing_system_with_fiber_screener(
-        ins=[feedstock_handling_sys-0, enzyme, H3PO4, lime, polymer],
+        area=200 if use_area_convention else None,
+        ins=[feedstock_handling_sys-0, H3PO4, lime, polymer],
+        pellet_bagasse=pellet_bagasse,
         mockup=True
     )
-    ethanol_production_sys = create_sucrose_to_ethanol_system(
+    ethanol_production_sys, edct = create_sucrose_to_ethanol_system(
+        area=300 if use_area_convention else None,
+        udct=True,
         ins=(juicing_sys-0, denaturant), outs=(ethanol, vinasse),
         mockup=True
     )
-    M305 = units.Mixer('M305', 
+    M305 = units.Mixer(400 if use_area_convention else 'M305', 
         ins=(juicing_sys-2, *ethanol_production_sys-[2, 3]),
         outs=wastewater
     )
     
     ### Facilities ###    
     
-    BT = units.BoilerTurbogenerator('BT',
+    BT = units.BoilerTurbogenerator(400 if use_area_convention else 'BT',
         (juicing_sys-1, '', 'boiler_makeup_water', 'natural_gas', '', ''),
         outs=(emissions, 'rejected_water_and_blowdown', ash_disposal),
         boiler_efficiency=0.80,
         turbogenerator_efficiency=0.85
     )
-    CT = units.CoolingTower('CT')
+    CT = units.CoolingTower(500 if use_area_convention else 'CT')
     makeup_water_streams = (s.cooling_tower_makeup_water,
                             s.boiler_makeup_water)
     process_water_streams = (s.imbibition_water,
@@ -704,17 +699,18 @@ def create_sugarcane_to_ethanol_system(ins, outs):
                              s.stripping_water,
                              *makeup_water_streams)
     makeup_water = bst.Stream('makeup_water', price=0.000254)
-    CWP = units.ChilledWaterPackage('CWP')
-    PWC = units.ProcessWaterCenter('PWC',
+    CWP = units.ChilledWaterPackage(500 if use_area_convention else 'CWP')
+    PWC = units.ProcessWaterCenter(500 if use_area_convention else 'PWC',
                                    (bst.Stream(), makeup_water),
                                    (),
                                    None,
                                    makeup_water_streams,
                                    process_water_streams)
     
-    F301 = u.F301
-    D303 = u.D303
-    HXN = bst.HeatExchangerNetwork('HXN', units=[F301, D303])
+    F301 = edct['F301']
+    D303 = edct['D303']
+    HXN = bst.HeatExchangerNetwork(600 if use_area_convention else 'HXN',
+                                   units=[F301, D303.condenser])
     
     # if vinasse_to_wastewater:
     #     plant_air = bst.Stream('plant_air', N2=83333, units='kg/hr')
