@@ -144,28 +144,6 @@ def print_results(tea):
     print('Electricity consumption:', units.get_electricity_consumption())
     print('Electricity production:', units.get_electricity_production())
     
-
-    bst.process_tools.default()
-    from biorefineries import corn as module
-    try: module.load()
-    except: pass
-    feedstock = module.corn
-    product = module.ethanol
-    tea = module.corn_tea
-    units = UnitGroup('Biorefinery', tea.units)
-    assert np.allclose(tea.IRR, 0.037843194745526644, rtol=1e-2)
-    assert np.allclose(feedstock.price, 0.13227735731092652, rtol=1e-2)
-    assert np.allclose(product.price, 0.48547915353569393, rtol=1e-2)
-    assert np.allclose(tea.sales, 73911402.04639979, rtol=1e-2)
-    assert np.allclose(tea.material_cost, 54229609.23083669, rtol=1e-2)
-    assert np.allclose(tea.installed_equipment_cost, 67931892.15209496, rtol=1e-2)
-    assert np.allclose(tea.utility_cost, 8267419.421774661, rtol=1e-2)
-    assert np.allclose(units.get_heating_duty(), 135.60034920381048, rtol=1e-2)
-    assert np.allclose(units.get_cooling_duty(), 141.00001509562642, rtol=1e-2)
-    assert np.allclose(units.get_electricity_consumption(), 2.340125651483439, rtol=1e-2)
-    assert np.allclose(units.get_electricity_production(), 0.0, rtol=1e-2)
-    bst.process_tools.default()
-    
 def test_corn():
     bst.process_tools.default()
     from biorefineries import corn as module
@@ -175,16 +153,16 @@ def test_corn():
     product = module.ethanol
     tea = module.corn_tea
     units = UnitGroup('Biorefinery', tea.units)
-    assert np.allclose(tea.IRR, 0.03989508733609, rtol=1e-2)
+    assert np.allclose(tea.IRR, 0.043717255501405476, rtol=1e-2)
     assert np.allclose(feedstock.price, 0.13227735731092652, rtol=1e-2)
     assert np.allclose(product.price, 0.48547915353569393, rtol=1e-2)
-    assert np.allclose(tea.sales, 73909879.42964743, rtol=1e-2)
-    assert np.allclose(tea.material_cost, 54229305.139442496, rtol=1e-2)
-    assert np.allclose(tea.installed_equipment_cost, 67980658.30941775, rtol=1e-2)
-    assert np.allclose(tea.utility_cost, 8136250.075012307, rtol=1e-2)
-    assert np.allclose(units.get_heating_duty(), 135.8019116579886, rtol=1e-2)
-    assert np.allclose(units.get_cooling_duty(), 139.05181894956826, rtol=1e-2)
-    assert np.allclose(units.get_electricity_consumption(), 2.33924346153039, rtol=1e-2)
+    assert np.allclose(tea.sales, 74722762.58928245, rtol=1e-2)
+    assert np.allclose(tea.material_cost, 55525145.78187931, rtol=1e-2)
+    assert np.allclose(tea.installed_equipment_cost, 67897818.46874477, rtol=1e-2)
+    assert np.allclose(tea.utility_cost, 7428866.365027555, rtol=1e-2)
+    assert np.allclose(units.get_heating_duty(), 94.03370431641385, rtol=1e-2)
+    assert np.allclose(units.get_cooling_duty(), 114.17250554942098, rtol=1e-2)
+    assert np.allclose(units.get_electricity_consumption(), 2.0737593308609013, rtol=1e-2)
     assert np.allclose(units.get_electricity_production(), 0.0, rtol=1e-2)
     bst.process_tools.default()
     
@@ -197,17 +175,17 @@ def test_lipidcane():
     product = module.ethanol
     tea = module.lipidcane_tea
     units = UnitGroup('Biorefinery', tea.units)
-    assert np.allclose(tea.IRR, 0.20278712010167085, rtol=1e-2)
+    assert np.allclose(tea.IRR, 0.21044396324964174, rtol=1e-2)
     assert np.allclose(feedstock.price, 0.03455, rtol=1e-2)
     assert np.allclose(product.price, 0.789, rtol=1e-2)
-    assert np.allclose(tea.sales, 108742778.87781802, rtol=1e-2)
-    assert np.allclose(tea.material_cost, 61700840.19858943, rtol=1e-2)
-    assert np.allclose(tea.installed_equipment_cost, 239131271.8859024, rtol=1e-2)
-    assert np.allclose(tea.utility_cost, -34243603.01673318, rtol=1e-2)
-    assert np.allclose(units.get_heating_duty(), 250.42519381527896, rtol=1e-2)
-    assert np.allclose(units.get_cooling_duty(), 279.5814981637738, rtol=1e-2)
-    assert np.allclose(units.get_electricity_consumption(), 16.437821814241584, rtol=1e-2)
-    assert np.allclose(units.get_electricity_production(), 125.44304849314373, rtol=1e-2)
+    assert np.allclose(tea.sales, 109496070.72655195, rtol=1e-2)
+    assert np.allclose(tea.material_cost, 59007868.15492096, rtol=1e-2)
+    assert np.allclose(tea.installed_equipment_cost, 206737567.7575963, rtol=1e-2)
+    assert np.allclose(tea.utility_cost, -22993515.584971845, rtol=1e-2)
+    assert np.allclose(units.get_heating_duty(), 264.2471619814205, rtol=1e-2)
+    assert np.allclose(units.get_cooling_duty(), 250.81603723349028, rtol=1e-2)
+    assert np.allclose(units.get_electricity_consumption(), 8.936873130121864, rtol=1e-2)
+    assert np.allclose(units.get_electricity_production(), 87.06007104266773, rtol=1e-2)
     bst.process_tools.default()
     
 def test_cornstover():
@@ -221,15 +199,15 @@ def test_cornstover():
     units = UnitGroup('Biorefinery', tea.units)
     assert np.allclose(tea.IRR, 0.1, rtol=1e-2)
     assert np.allclose(feedstock.price, 0.05158816935126135, rtol=1e-2)
-    assert np.allclose(product.price, 0.7141047799147656, rtol=1e-2)
-    assert np.allclose(tea.sales, 131519594.87222457, rtol=1e-2)
-    assert np.allclose(tea.material_cost, 82696666.93499637, rtol=1e-2)
-    assert np.allclose(tea.installed_equipment_cost, 213729761.48123008, rtol=1e-2)
-    assert np.allclose(tea.utility_cost, -12216823.378096422, rtol=1e-2)
-    assert np.allclose(units.get_heating_duty(), 308.3841985204103, rtol=1e-2)
-    assert np.allclose(units.get_cooling_duty(), 298.4404395355398, rtol=1e-2)
-    assert np.allclose(units.get_electricity_consumption(), 21.456532820335028, rtol=1e-2)
-    assert np.allclose(units.get_electricity_production(), 46.85379645812982, rtol=1e-2)
+    assert np.allclose(product.price, 0.7350995079509869, rtol=1e-2)
+    assert np.allclose(tea.sales, 135782970.45044357, rtol=1e-2)
+    assert np.allclose(tea.material_cost, 82430522.10931535, rtol=1e-2)
+    assert np.allclose(tea.installed_equipment_cost, 215543598.15247896, rtol=1e-2)
+    assert np.allclose(tea.utility_cost, -9000624.589971658, rtol=1e-2)
+    assert np.allclose(units.get_heating_duty(), 310.12068230830573, rtol=1e-2)
+    assert np.allclose(units.get_cooling_duty(), 360.88487080960493, rtol=1e-2)
+    assert np.allclose(units.get_electricity_consumption(), 24.318643728850052, rtol=1e-2)
+    assert np.allclose(units.get_electricity_production(), 46.18747108900341, rtol=1e-2)
     bst.process_tools.default()
     
 def test_sugarcane():
@@ -241,17 +219,17 @@ def test_sugarcane():
     product = module.ethanol
     tea = module.sugarcane_tea
     units = UnitGroup('Biorefinery', tea.units)
-    assert np.allclose(tea.IRR, 0.12659387829384772, rtol=1e-2)
+    assert np.allclose(tea.IRR, 0.13109423607427642, rtol=1e-2)
     assert np.allclose(feedstock.price, 0.03455, rtol=1e-2)
     assert np.allclose(product.price, 0.789, rtol=1e-2)
-    assert np.allclose(tea.sales, 88129976.99654803, rtol=1e-2)
-    assert np.allclose(tea.material_cost, 59842659.397153035, rtol=1e-2)
-    assert np.allclose(tea.installed_equipment_cost, 205172809.39941, rtol=1e-2)
-    assert np.allclose(tea.utility_cost, -19201338.64548274, rtol=1e-2)
-    assert np.allclose(units.get_heating_duty(), 284.23468528204995, rtol=1e-2)
-    assert np.allclose(units.get_cooling_duty(), 304.1271932338852, rtol=1e-2)
-    assert np.allclose(units.get_electricity_consumption(), 15.82128374128548, rtol=1e-2)
-    assert np.allclose(units.get_electricity_production(), 76.76409793701727, rtol=1e-2)
+    assert np.allclose(tea.sales, 88302100.19471487, rtol=1e-2)
+    assert np.allclose(tea.material_cost, 57416005.959415175, rtol=1e-2)
+    assert np.allclose(tea.installed_equipment_cost, 173943685.0002066, rtol=1e-2)
+    assert np.allclose(tea.utility_cost, -11090808.725935081, rtol=1e-2)
+    assert np.allclose(units.get_heating_duty(), 274.9313475699405, rtol=1e-2)
+    assert np.allclose(units.get_cooling_duty(), 274.71740599119045, rtol=1e-2)
+    assert np.allclose(units.get_electricity_consumption(), 9.538693560979029, rtol=1e-2)
+    assert np.allclose(units.get_electricity_production(), 49.50098872470631, rtol=1e-2)
     bst.process_tools.default()
     
 def test_LAOs():
@@ -265,15 +243,15 @@ def test_LAOs():
     units = UnitGroup('Biorefinery', tea.units)
     assert np.allclose(tea.IRR, 0.1, rtol=1e-2)
     assert np.allclose(feedstock.price, 0.265, rtol=1e-2)
-    assert np.allclose(product.price, 1.3269049845098067, rtol=1e-2)
-    assert np.allclose(tea.sales, 161335906.29907194, rtol=1e-2)
-    assert np.allclose(tea.material_cost, 135661164.88724267, rtol=1e-2)
-    assert np.allclose(tea.installed_equipment_cost, 57347781.65516735, rtol=1e-2)
-    assert np.allclose(tea.utility_cost, 1554844.4698447809, rtol=1e-2)
-    assert np.allclose(units.get_heating_duty(), 39.587331392856626, rtol=1e-2)
-    assert np.allclose(units.get_cooling_duty(), 127.39469106251019, rtol=1e-2)
-    assert np.allclose(units.get_electricity_consumption(), 3.5306112844050603, rtol=1e-2)
-    assert np.allclose(units.get_electricity_production(), 7.271296144805024, rtol=1e-2)
+    assert np.allclose(product.price, 1.3077031239523305, rtol=1e-2)
+    assert np.allclose(tea.sales, 158913806.8745284, rtol=1e-2)
+    assert np.allclose(tea.material_cost, 135664645.25854838, rtol=1e-2)
+    assert np.allclose(tea.installed_equipment_cost, 53924928.30015353, rtol=1e-2)
+    assert np.allclose(tea.utility_cost, 526598.6753808785, rtol=1e-2)
+    assert np.allclose(units.get_heating_duty(), 37.83052976222895, rtol=1e-2)
+    assert np.allclose(units.get_cooling_duty(), 123.63183824839172, rtol=1e-2)
+    assert np.allclose(units.get_electricity_consumption(), 3.7688464540404114, rtol=1e-2)
+    assert np.allclose(units.get_electricity_production(), 3.768846454040413, rtol=1e-2)
     bst.process_tools.default()
     
 def test_lactic():
@@ -285,19 +263,20 @@ def test_lactic():
     tea = module.lactic_tea
     units = UnitGroup('Biorefinery', tea.units)
     module.lactic_sys.simulate()
+    product.price = product_price = tea.solve_price(product)
     assert np.allclose(tea.IRR, 0.1, rtol=1e-2)
     assert np.allclose(feedstock.price, 0.06287583717512708, rtol=1e-2)
-    assert np.allclose(tea.solve_price(product), 1.237548148885074, rtol=1e-2)
-    assert np.allclose(tea.sales, 54143215.78374311, rtol=1e-2)
-    assert np.allclose(tea.material_cost, 219104068.95373908, rtol=1e-2)
-    assert np.allclose(tea.installed_equipment_cost, 320073822.05670184, rtol=1e-2)
-    assert np.allclose(tea.utility_cost, 22275814.89016047, rtol=1e-2)
-    assert np.allclose(units.get_heating_duty(), 1827.5926437830065, rtol=1e-2)
-    assert np.allclose(units.get_cooling_duty(), 1895.6520852552394, rtol=1e-2)
-    assert np.allclose(units.get_electricity_consumption(), 40.363511796333356, rtol=1e-2)
+    assert np.allclose(product.price, 1.365160205800196, rtol=1e-2)
+    assert np.allclose(tea.sales, 297352245.8641948, rtol=1e-2)
+    assert np.allclose(tea.material_cost, 202146016.56312773, rtol=1e-2)
+    assert np.allclose(tea.installed_equipment_cost, 282073346.9023893, rtol=1e-2)
+    assert np.allclose(tea.utility_cost, 20669375.58387342, rtol=1e-2)
+    assert np.allclose(units.get_heating_duty(), 1842.5273042407728, rtol=1e-2)
+    assert np.allclose(units.get_cooling_duty(), 1786.5220868424758, rtol=1e-2)
+    assert np.allclose(units.get_electricity_consumption(), 37.452662868510195, rtol=1e-2)
     assert np.allclose(units.get_electricity_production(), 0.0, rtol=1e-2)
     bst.process_tools.default()
-    
+
 # Work is ongoing, at this stage, it is fine as long as these modules can load
 # and systems can be simulated
 def test_ethanol_adipic():
@@ -411,14 +390,14 @@ def test_animal_bedding():
 #     assert np.allclose(units.get_electricity_consumption(), 26.565278642577344, rtol=0.001)
 #     assert np.allclose(units.get_electricity_production(), 0.0)
     
-# if __name__ == '__main__':
-    # test_corn()
-    # test_sugarcane()
-    # test_lipidcane()
-    # test_cornstover()
-    # # test_HP_cellulosic()
-    # # test_HP_sugarcane()
-    # test_LAOs()
+if __name__ == '__main__':
+    test_corn()
+    test_sugarcane()
+    test_lipidcane()
+    test_cornstover()
+    # test_HP_cellulosic()
+    # test_HP_sugarcane()
+    test_LAOs()
     # test_lactic()
     # test_ethanol_adipic()
 
